@@ -137,37 +137,38 @@ enum : int {
     SBK_QQMLCOMPONENT_STATUS_IDX                             = 22,
     SBK_QQMLCOMPONENT_IDX                                    = 20,
     SBK_QQMLCONTEXT_IDX                                      = 23,
-    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 25,
-    SBK_QQMLDEBUGGINGENABLER_IDX                             = 24,
-    SBK_QQMLENGINE_IDX                                       = 26,
-    SBK_QQMLERROR_IDX                                        = 27,
-    SBK_QQMLEXPRESSION_IDX                                   = 28,
-    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 29,
-    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 30,
-    SBK_QQMLFILE_STATUS_IDX                                  = 32,
-    SBK_QQMLFILE_IDX                                         = 31,
-    SBK_QQMLFILESELECTOR_IDX                                 = 33,
-    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 36,
-    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 35,
+    SBK_QQMLCONTEXT_PROPERTYPAIR_IDX                         = 24,
+    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 26,
+    SBK_QQMLDEBUGGINGENABLER_IDX                             = 25,
+    SBK_QQMLENGINE_IDX                                       = 27,
+    SBK_QQMLERROR_IDX                                        = 28,
+    SBK_QQMLEXPRESSION_IDX                                   = 29,
+    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 30,
+    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 31,
+    SBK_QQMLFILE_STATUS_IDX                                  = 33,
+    SBK_QQMLFILE_IDX                                         = 32,
+    SBK_QQMLFILESELECTOR_IDX                                 = 34,
+    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 37,
+    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 36,
     SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX                = 1,
-    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 34,
-    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 37,
-    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 39,
-    SBK_QQMLINCUBATOR_STATUS_IDX                             = 40,
-    SBK_QQMLINCUBATOR_IDX                                    = 38,
-    SBK_QQMLLISTREFERENCE_IDX                                = 41,
-    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 43,
-    SBK_QQMLPARSERSTATUS_IDX                                 = 44,
-    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 46,
-    SBK_QQMLPROPERTY_TYPE_IDX                                = 47,
-    SBK_QQMLPROPERTY_IDX                                     = 45,
-    SBK_QQMLPROPERTYMAP_IDX                                  = 48,
-    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 49,
-    SBK_QQMLSCRIPTSTRING_IDX                                 = 50,
-    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 51,
+    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 35,
+    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 38,
+    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 40,
+    SBK_QQMLINCUBATOR_STATUS_IDX                             = 41,
+    SBK_QQMLINCUBATOR_IDX                                    = 39,
+    SBK_QQMLLISTREFERENCE_IDX                                = 42,
+    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 44,
+    SBK_QQMLPARSERSTATUS_IDX                                 = 45,
+    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 47,
+    SBK_QQMLPROPERTY_TYPE_IDX                                = 48,
+    SBK_QQMLPROPERTY_IDX                                     = 46,
+    SBK_QQMLPROPERTYMAP_IDX                                  = 49,
+    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 50,
+    SBK_QQMLSCRIPTSTRING_IDX                                 = 51,
+    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 52,
     SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 14,
-    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 42,
-    SBK_QtQml_IDX_COUNT                                      = 53
+    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 43,
+    SBK_QtQml_IDX_COUNT                                      = 54
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtQmlTypes;
@@ -187,10 +188,11 @@ enum : int {
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 4, // QList<QJSValue >
     SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 5, // QList<QObject* >
     SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 6, // QList<QByteArray >
-    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 7, // QList<QQmlAbstractUrlInterceptor* >
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 8, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 9, // QList<QString >
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 10
+    SBK_QTQML_QLIST_QQMLCONTEXT_PROPERTYPAIR_IDX             = 7, // QList<QQmlContext::PropertyPair >
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 8, // QList<QQmlAbstractUrlInterceptor* >
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 9, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 10, // QList<QString >
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 11
 };
 // Macros for type check
 
@@ -223,6 +225,7 @@ template<> inline PyTypeObject *SbkType< ::QQmlComponent::CompilationMode >() {
 template<> inline PyTypeObject *SbkType< ::QQmlComponent::Status >() { return SbkPySide6_QtQmlTypes[SBK_QQMLCOMPONENT_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlComponent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCOMPONENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlContext >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCONTEXT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlContext::PropertyPair >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCONTEXT_PROPERTYPAIR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler::StartMode >() { return SbkPySide6_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLENGINE_IDX]); }
